==> google-cloud-aiplatform-1.5.0.tar.gz: google-cloud-aiplatform-1.5.0/google/cloud/aiplatform_v1/services/vizier_service/pagers.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import (
    Any,
    AsyncIterable,
    Awaitable,
    Callable,
    Iterable,
    Sequence,
    Tuple,
    Optional,
)

from google.cloud.aiplatform_v1.types import study
from google.cloud.aiplatform_v1.types import vizier_service


class ListStudiesPager:
    """A pager for iterating through ``list_studies`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.aiplatform_v1.types.ListStudiesResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``studies`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListStudies`` requests and continue to iterate
    through the ``studies`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.aiplatform_v1.types.ListStudiesResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., vizier_service.ListStudiesResponse],
        request: vizier_service.ListStudiesRequest,
        response: vizier_service.ListStudiesResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.aiplatform_v1.types.ListStudiesRequest):
                The initial request object.
            response (google.cloud.aiplatform_v1.types.ListStudiesResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = vizier_service.ListStudiesRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterable[vizier_service.ListStudiesResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterable[study.Study]:
        for page in self.pages:
            yield from page.studies

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListStudiesAsyncPager:
    """A pager for iterating through ``list_studies`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.aiplatform_v1.types.ListStudiesResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``studies`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``ListStudies`` requests and continue to iterate
    through the ``studies`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.aiplatform_v1.types.ListStudiesResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., Awaitable[vizier_service.ListStudiesResponse]],
        request: vizier_service.ListStudiesRequest,
        response: vizier_service.ListStudiesResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiates the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.aiplatform_v1.types.ListStudiesRequest):
                The initial request object.
            response (google.cloud.aiplatform_v1.types.ListStudiesResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = vizier_service.ListStudiesRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(self) -> AsyncIterable[vizier_service.ListStudiesResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(self) -> AsyncIterable[study.Study]:
        async def async_generator():
            async for page in self.pages:
                for response in page.studies:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListTrialsPager:
    """A pager for iterating through ``list_trials`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.aiplatform_v1.types.ListTrialsResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``trials`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListTrials`` requests and continue to iterate
    through the ``trials`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.aiplatform_v1.types.ListTrialsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., vizier_service.ListTrialsResponse],
        request: vizier_service.ListTrialsRequest,
        response: vizier_service.ListTrialsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.aiplatform_v1.types.ListTrialsRequest):
                The initial request object.
            response (google.cloud.aiplatform_v1.types.ListTrialsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = vizier_service.ListTrialsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterable[vizier_service.ListTrialsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterable[study.Trial]:
        for page in self.pages:
            yield from page.trials

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListTrialsAsyncPager:
    """A pager for iterating through ``list_trials`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.aiplatform_v1.types.ListTrialsResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``trials`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``ListTrials`` requests and continue to iterate
    through the ``trials`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.aiplatform_v1.types.ListTrialsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., Awaitable[vizier_service.ListTrialsResponse]],
        request: vizier_service.ListTrialsRequest,
        response: vizier_service.ListTrialsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiates the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.aiplatform_v1.types.ListTrialsRequest):
                The initial request object.
            response (google.cloud.aiplatform_v1.types.ListTrialsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = vizier_service.ListTrialsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(self) -> AsyncIterable[vizier_service.ListTrialsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(self) -> AsyncIterable[study.Trial]:
        async def async_generator():
            async for page in self.pages:
                for response in page.trials:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)

==> google-cloud-aiplatform-1.56.0.tar.gz: google-cloud-aiplatform-1.56.0/google/cloud/aiplatform_v1/services/vizier_service/pagers.py <==
# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import (
    Any,
    AsyncIterator,
    Awaitable,
    Callable,
    Sequence,
    Tuple,
    Optional,
    Iterator,
)

from google.cloud.aiplatform_v1.types import study
from google.cloud.aiplatform_v1.types import vizier_service


class ListStudiesPager:
    """A pager for iterating through ``list_studies`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.aiplatform_v1.types.ListStudiesResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``studies`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListStudies`` requests and continue to iterate
    through the ``studies`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.aiplatform_v1.types.ListStudiesResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., vizier_service.ListStudiesResponse],
        request: vizier_service.ListStudiesRequest,
        response: vizier_service.ListStudiesResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.aiplatform_v1.types.ListStudiesRequest):
                The initial request object.
            response (google.cloud.aiplatform_v1.types.ListStudiesResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = vizier_service.ListStudiesRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[vizier_service.ListStudiesResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterator[study.Study]:
        for page in self.pages:
            yield from page.studies

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListStudiesAsyncPager:
    """A pager for iterating through ``list_studies`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.aiplatform_v1.types.ListStudiesResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``studies`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``ListStudies`` requests and continue to iterate
    through the ``studies`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.aiplatform_v1.types.ListStudiesResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., Awaitable[vizier_service.ListStudiesResponse]],
        request: vizier_service.ListStudiesRequest,
        response: vizier_service.ListStudiesResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiates the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.aiplatform_v1.types.ListStudiesRequest):
                The initial request object.
            response (google.cloud.aiplatform_v1.types.ListStudiesResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = vizier_service.ListStudiesRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(self) -> AsyncIterator[vizier_service.ListStudiesResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(self) -> AsyncIterator[study.Study]:
        async def async_generator():
            async for page in self.pages:
                for response in page.studies:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListTrialsPager:
    """A pager for iterating through ``list_trials`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.aiplatform_v1.types.ListTrialsResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``trials`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListTrials`` requests and continue to iterate
    through the ``trials`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.aiplatform_v1.types.ListTrialsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., vizier_service.ListTrialsResponse],
        request: vizier_service.ListTrialsRequest,
        response: vizier_service.ListTrialsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.aiplatform_v1.types.ListTrialsRequest):
                The initial request object.
            response (google.cloud.aiplatform_v1.types.ListTrialsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = vizier_service.ListTrialsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[vizier_service.ListTrialsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterator[study.Trial]:
        for page in self.pages:
            yield from page.trials

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListTrialsAsyncPager:
    """A pager for iterating through ``list_trials`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.aiplatform_v1.types.ListTrialsResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``trials`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``ListTrials`` requests and continue to iterate
    through the ``trials`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.aiplatform_v1.types.ListTrialsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., Awaitable[vizier_service.ListTrialsResponse]],
        request: vizier_service.ListTrialsRequest,
        response: vizier_service.ListTrialsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiates the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.aiplatform_v1.types.ListTrialsRequest):
                The initial request object.
            response (google.cloud.aiplatform_v1.types.ListTrialsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = vizier_service.ListTrialsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(self) -> AsyncIterator[vizier_service.ListTrialsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(self) -> AsyncIterator[study.Trial]:
        async def async_generator():
            async for page in self.pages:
                for response in page.trials:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)
